@@ -6,6 +6,8 @@ pub mod alert_event_type_enum;
 pub use self::alert_event_type_enum::AlertEventTypeEnum;
 pub mod alert_request;
 pub use self::alert_request::AlertRequest;
+pub mod ansible_extra_vars;
+pub use self::ansible_extra_vars::AnsibleExtraVars;
 pub mod ansible_state_enum;
 pub use self::ansible_state_enum::AnsibleStateEnum;
 pub mod artifact_types_enum;
@@ -30,14 +32,6 @@ pub mod cloudiot_device_request;
 pub use self::cloudiot_device_request::CloudiotDeviceRequest;
 pub mod command_enum;
 pub use self::command_enum::CommandEnum;
-pub mod current_state;
-pub use self::current_state::CurrentState;
-pub mod current_state_request;
-pub use self::current_state_request::CurrentStateRequest;
-pub mod desired_config;
-pub use self::desired_config::DesiredConfig;
-pub mod desired_config_request;
-pub use self::desired_config_request::DesiredConfigRequest;
 pub mod detail_response;
 pub use self::detail_response::DetailResponse;
 pub mod device;
@@ -46,12 +40,20 @@ pub mod device_calibration;
 pub use self::device_calibration::DeviceCalibration;
 pub mod device_calibration_request;
 pub use self::device_calibration_request::DeviceCalibrationRequest;
+pub mod device_config;
+pub use self::device_config::DeviceConfig;
+pub mod device_config_request;
+pub use self::device_config_request::DeviceConfigRequest;
 pub mod device_key_pair;
 pub use self::device_key_pair::DeviceKeyPair;
 pub mod device_public_key;
 pub use self::device_public_key::DevicePublicKey;
 pub mod device_request;
 pub use self::device_request::DeviceRequest;
+pub mod device_state;
+pub use self::device_state::DeviceState;
+pub mod device_state_request;
+pub use self::device_state_request::DeviceStateRequest;
 pub mod email_auth_request;
 pub use self::email_auth_request::EmailAuthRequest;
 pub mod error_detail;
@@ -132,16 +134,16 @@ pub mod paginated_camera_list;
 pub use self::paginated_camera_list::PaginatedCameraList;
 pub mod paginated_cloudiot_device_list;
 pub use self::paginated_cloudiot_device_list::PaginatedCloudiotDeviceList;
-pub mod paginated_current_state_list;
-pub use self::paginated_current_state_list::PaginatedCurrentStateList;
-pub mod paginated_desired_config_list;
-pub use self::paginated_desired_config_list::PaginatedDesiredConfigList;
 pub mod paginated_device_calibration_list;
 pub use self::paginated_device_calibration_list::PaginatedDeviceCalibrationList;
+pub mod paginated_device_config_list;
+pub use self::paginated_device_config_list::PaginatedDeviceConfigList;
 pub mod paginated_device_list;
 pub use self::paginated_device_list::PaginatedDeviceList;
 pub mod paginated_device_public_key_list;
 pub use self::paginated_device_public_key_list::PaginatedDevicePublicKeyList;
+pub mod paginated_device_state_list;
+pub use self::paginated_device_state_list::PaginatedDeviceStateList;
 pub mod paginated_experiment_device_config_list;
 pub use self::paginated_experiment_device_config_list::PaginatedExperimentDeviceConfigList;
 pub mod paginated_experiment_list;
@@ -164,6 +166,8 @@ pub mod paginated_printer_controller_list;
 pub use self::paginated_printer_controller_list::PaginatedPrinterControllerList;
 pub mod paginated_printer_profile_list;
 pub use self::paginated_printer_profile_list::PaginatedPrinterProfileList;
+pub mod paginated_release_list;
+pub use self::paginated_release_list::PaginatedReleaseList;
 pub mod paginated_remote_command_event_list;
 pub use self::paginated_remote_command_event_list::PaginatedRemoteCommandEventList;
 pub mod paginated_remote_control_command_list;
@@ -230,6 +234,8 @@ pub mod printer_profile_request;
 pub use self::printer_profile_request::PrinterProfileRequest;
 pub mod printer_state_enum;
 pub use self::printer_state_enum::PrinterStateEnum;
+pub mod release;
+pub use self::release::Release;
 pub mod release_channel_enum;
 pub use self::release_channel_enum::ReleaseChannelEnum;
 pub mod remote_command_event;
